import QtQuick 1.0
import com.nokia.meego 1.0
import myExplorer.types 1.0
import "Dynamic.js" as Dynamic
import "DynamicGlobal.js" as DynamicGlobal

Page {
    tools: folderTools

    function open(popup)
    {
        folderForm.StopScroll();
        popup.open();
    }

    ToolBarLayout {
        id: folderTools
        visible: false

        MilToolButton {
            platformIconId: "toolbar-back"
            onClicked: folderForm.cmdBack();
            tipText: qsTr("Back");
        }

        MilToolButton {
            platformIconId: "toolbar-search"
            onClicked: sbox.show();
            tipText: qsTr("Filter / Search")
        }

        MilToolButton {
            platformIconId: "toolbar-list"
            onClicked: open(folderForm.loadMenu("SelectMenu"));
            tipText: qsTr("Select")
        }

        MilToolButton {
            iconSource: app.InvertedTheme() ? "qrc:/resources/tbicons/paste.svg" : "qrc:/resources/tbicons/paste_inverse.svg"
            onClicked: folderForm.PasteCmd();
            tipText: qsTr("Paste")
            enabled: folderForm.pasteEnabled
        }


        MilToolButton {
            platformIconId: "toolbar-view-menu"
            anchors.right: (parent === undefined) ? undefined : parent.right
            onClicked: open(folderForm.loadMenu("FolderMenu"));
            tipText: qsTr("Show menu")
        }
    }

    TitleBar {
        id: titleBar
        small: true
        titleText: folderForm.titleText
        inverted: app.InvertedTheme();

        MouseArea {
            anchors.fill: parent
            onClicked: folderForm.cmdShowTreeDialog();
        }

        function show() {
            visible = true;
            y = 0;
        }

        function hide() {
            y = -titleBar.height;
            visible = false;
        }
    }

    Item {
        id: menus
        anchors.fill: parent
        visible: false
    }

    QtObject {
        id: d

        property variant aDlgSelShare: null
        property variant aTransfer: null
        property variant aTreeDlg: null
        property variant aDelDetails: null
        property variant aFileDetails: null
        property variant aSelDetails: null
        property variant aLoginDlg: null
        property variant aRenameDlg: null
        property variant aNewFolderDlg: null
        property variant aPwdDlg: null
        property variant aWaitDlg: null

        Component.onDestruction: {
            if (aTransfer) aTransfer.destroy(500);
            if (aTreeDlg) aTreeDlg.destroy(500);
            if (aDelDetails) aDelDetails.destroy(500);
            if (aFileDetails) aFileDetails.destroy(500);
            if (aSelDetails) aSelDetails.destroy(500);
            if (aLoginDlg) aLoginDlg.destroy(500);
            if (aRenameDlg) aRenameDlg.destroy(500);
            if (aNewFolderDlg) aNewFolderDlg.destroy(500);
            if (aPwdDlg) aPwdDlg.destroy(500);
            if (aWaitDlg) aWaitDlg.destroy(500);
        }

        function transfer() {
            return aTransfer = DynamicGlobal.createObject(aTransfer, "TransferDialog.qml");
        }

        function overwrite() {
            return Dynamic.createObject(null, "OverwriteDialog.qml");
        }

        function cmdShowShareSelDialog() {
            initSelShareDialog();
            aDlgSelShare.selectedIndex = 0;
            open(aDlgSelShare);
            aDlgSelShare = null; // It will self-destruct
        }

        function cmdAddShareSel(share) {
            initSelShareDialog();
            aDlgSelShare.addShare(share);
        }

        function cmdClearShares() {
            initSelShareDialog();
            aDlgSelShare.clearShares();
        }

        function initSelShareDialog() {
            if (aDlgSelShare)
                return;

            console.log("Create sel share dialog!");
            aDlgSelShare = Dynamic.createObject(aDlgSelShare, "SelectShareDialog.qml");
            aDlgSelShare.rejected.connect(folderForm.OnShareSelRejected);
            aDlgSelShare.shareSelected.connect(folderForm.OnShareSelAccepted);
        }

        function delDetails() {
            return aDelDetails = DynamicGlobal.createObject(aDelDetails, "DeleteDetailsDialog.qml");
        }

        function fileDetails() {
            return aFileDetails = DynamicGlobal.createObject(aFileDetails, "FileDetailsDialog.qml");
        }

        function selDetails() {
            return aSelDetails = DynamicGlobal.createObject(aSelDetails, "SelDetailsDialog.qml");
        }
    }

    ListModel {
        id: treeModel
    }

    QmlFolderForm {
        id: folderForm
        anchors.top: titleBar.bottom;
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom

        property variant mFolderMenu1: null
        property variant mFolderMenu2: null
        property variant mFolderMenu3: null
        property variant mFolderMenu4: null
        property variant mFolderMenu5: null
        property variant mFolderMenu11: null
        property variant mFolderMenu12: null
        property variant mFolderMenu13: null
        property variant mSelectMenu: null
        property variant mFolderMenu: null

        function loadCtxMenu(mname) {
            var pname = "m" + mname;
            return folderForm[pname] = DynamicGlobal.createObject(folderForm[pname], mname + ".qml", {form: folderForm}, menus);
        }

        function loadMenu(mname) {
            var pname = "m" + mname;
            return folderForm[pname] = DynamicGlobal.createObject(folderForm[pname], mname + ".qml", null, menus);
        }

        function ctxMenuStatusChanged(status) {
            if (status === DialogStatus.Closing)
                folderForm.CtxMenuClosed();
        }

        function cmdShowWaitDialog(message, showCancel)
        {
            d.aWaitDlg = DynamicGlobal.createObject(d.aWaitDlg, "WaitDialog.qml", {
                                                        titleText: message,
                                                        showCancel: showCancel });
            d.aWaitDlg.open();
        }

        function cmdHideWaitDialog()
        {
            if (d.aWaitDlg)
                d.aWaitDlg.close();
        }

        function cmdBack() { folderForm.OnFolderBack(); }

        function cmdShowTreeDialog() {
            d.aTreeDlg = Dynamic.createObject(d.aTreeDlg, "TreeDialog.qml", { model: treeModel, form: folderForm });
            d.aTreeDlg.selectedIndex = 0;
            open(d.aTreeDlg);
        }

        function onTreeDlgAccepted(selectedIndex) {
            cmdResetSearchBox();
            folderForm.OnTreeDlgAccepted(selectedIndex);
        }

        function cmdClearTreeItems() { treeModel.clear(); }
        function cmdAddTreeItem(folderName) { treeModel.append({"name":folderName}) }

        function cmdShowFolderMenu1() { open(loadCtxMenu("FolderMenu1")); }
        function cmdShowFolderMenu2() { open(loadCtxMenu("FolderMenu2")); }
        function cmdShowFolderMenu3() { open(loadCtxMenu("FolderMenu3")); }
        function cmdShowFolderMenu4() { open(loadCtxMenu("FolderMenu4")); }
        function cmdShowFolderMenu5() { open(loadCtxMenu("FolderMenu5")); }
        function cmdShowFolderMenu11() { open(loadCtxMenu("FolderMenu11")); }
        function cmdShowFolderMenu12() { open(loadCtxMenu("FolderMenu12")); }
        function cmdShowFolderMenu13() { open(loadCtxMenu("FolderMenu13")); }

        function cmdShowRenameDialog(fileName)
        {
            d.aRenameDlg = DynamicGlobal.createObject(d.aRenameDlg, "RenameDialog.qml",
                                                      { fileName: fileName });
            open(d.aRenameDlg);
        }

        function cmdShowNewFolderDialog(folderName)
        {
            d.aNewFolderDlg = DynamicGlobal.createObject(d.aNewFolderDlg, "NewFolderDialog.qml",
                                                         { folderName: folderName });
            open(d.aNewFolderDlg);
        }

        function cmdShowShareSelDialog() { d.cmdShowShareSelDialog(); }
        function cmdAddShareSel(share) { d.cmdAddShareSel(share); }
        function cmdClearShares() { d.cmdClearShares(); }

        function cmdShowLoginDialog(uncName, userName, password, remember)
        {
            d.aLoginDlg = DynamicGlobal.createObject(d.aLoginDlg, "LoginDialog.qml", {
                                               titleText: uncName,
                                               userName: userName,
                                               password: password,
                                               rememberPassword: remember
                                           });

            open(d.aLoginDlg);
        }

        function cmdShowPasswordDialog()
        {
            d.aPwdDlg = DynamicGlobal.createObject(d.aPwdDlg, "PasswordDialog.qml", { password: "" });
            open(d.aPwdDlg);
        }

        function cmdShowRenameExtWarning() {
            var aDlg = Dynamic.createObject(null, autoDlgComp, {
                                              message: qsTr("If you change the file name extension, the file may become unusable.\n\nDo you want to change it?"),
                                              acceptButtonText: qsTr("Yes"),
                                              rejectButtonText: qsTr("No") }
                                          );
            aDlg.accepted.connect(folderForm.OnRenameExtAccepted);
            open(aDlg);
        }

        function cmdShowRenameRoWarning(msg) {
            var aDlg = Dynamic.createObject(null, autoDlgComp, {
                                              message: msg,
                                              acceptButtonText: qsTr("Yes"),
                                              rejectButtonText: qsTr("No") }
                                          );
            aDlg.accepted.connect(folderForm.OnRenameRoAccepted);
            open(aDlg);
        }

        function cmdShowDeleteWarning(msg) {
            var aDlg = Dynamic.createObject(null, autoDlgComp, {
                                              message: msg,
                                              acceptButtonText: qsTr("Yes"),
                                              rejectButtonText: qsTr("No") }
                                          );
            aDlg.accepted.connect(folderForm.OnDeleteAccepted);
            open(aDlg);
        }

        function cmdShowSelDeleteWarning(msg) {
            var aDlg = Dynamic.createObject(null, autoDlgComp, {
                                              message: msg,
                                              acceptButtonText: qsTr("Yes"),
                                              rejectButtonText: qsTr("No") }
                                          );
            aDlg.accepted.connect(folderForm.OnSelDeleteAccepted);
            open(aDlg);
        }

        function cmdResetSearchBox() {
            if (sbox.visible)
                sbox.close();
            sbox.clear();
        }

        function createTransferDialog() { return d.transfer(); }
        function createOverwriteDialog() { return d.overwrite(); }
        function createDeleteDetailsDialog() { return d.delDetails(); }
        function createFileDetailsDialog() { return d.fileDetails(); }
        function createSelDetailsDialog() { return d.selDetails(); }
    }

    MilSearchBox {
        id: sbox
        backButton: true
        platformInverted: app.InvertedTheme();
        anchors { left: parent.left; right: parent.right; bottom: parent.bottom; }
        visible: false;
        placeHolderText: qsTr("Enter search pattern")
        property bool isActive: true

        function show() {
            if (sbox.visible)
                return;
            folderForm.StopScroll();
            folderForm.anchors.bottom = sbox.top
            appWindow.showToolBar = false;
            titleBar.hide();
            sbox.visible = true;
            sbox.showKbd();
        }

        function close() {
            if (!sbox.visible)
                return;
            folderForm.StopScroll();
            folderForm.anchors.bottom = parent.bottom
            sbox.visible = false;
            appWindow.showToolBar = true;
            titleBar.show();
        }

        function clear() {
            searchText = "";
        }

        onBackClicked: close();
        onSearchTextChanged: if (sbox.visible) folderForm.OnSearchTextChanging(searchText.toString());
    }

    onStatusChanged: {
        folderForm.StopScroll();

        if (sbox.visible && status === PageStatus.Activating) {
            appWindow.showToolBar = false;
            titleBar.hide();
        }
    }

    Component.onCompleted: app.OnFolderFormLoaded(folderForm);
}

