import QtQuick 1.1
import com.nokia.meego 1.0
import myExplorer.types 1.0
import "Dynamic.js" as Dynamic
import "DynamicGlobal.js" as DynamicGlobal

Page {
    tools: commonTools

    ToolBarLayout {
        id: commonTools
        visible: false

        MilToolButton {
            platformIconId: "toolbar-close"
            onClicked: appWindow.cmdExit();
            tipText: qsTr("Exit myExplorer")
        }

        MilToolButton {
            platformIconId: "toolbar-add"
            onClicked: cmdAddNetworkFolder();
            tipText: qsTr("Add network share")
        }

        MilToolButton {
            platformIconId: "toolbar-settings"
            onClicked: app.OnSettings();
            tipText: qsTr("Settings")
        }

        MilToolButton {
            platformIconId: "toolbar-view-menu"
            anchors.right: (parent === undefined) ? undefined : parent.right
            onClicked: appWindow.getGlobalCachedMenu("MainFormMainMenu").open();
            tipText: qsTr("Open menu")
        }
    }

    TitleBar {
        id: titleBar
        titleText: "myExplorer"
        inverted: app.InvertedTheme();

        MouseArea {
            anchors.fill: parent
            onClicked: appWindow.aboutDlg();
        }
    }

    Item
    {
        id: menus
        anchors.fill: parent
        visible: false
    }

    Item {
        id: dlg

        property alias dlgVolDetails: dlgVolDetails

        Loader
        {
            id: dlgVolDetails
            width: parent.width - 20
        }
    }

    QmlMainForm {
        id: mainForm
        anchors.top: titleBar.bottom;
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom

        property variant mVolMenu1: null
        property variant mVolMenu2: null
        property variant mVolMenu3: null

        function loadCtxMenu(mname) {
            var pname = "m" + mname;
            return mainForm[pname] = DynamicGlobal.createObject(mainForm[pname], mname + ".qml", {form: mainForm}, menus);
        }

        function ctxMenuStatusChanged(status) {
            if (status === DialogStatus.Closing)
                mainForm.CtxMenuClosed();
        }

        function cmdShowVolMenu1() { loadCtxMenu("VolMenu1").open(); }
        function cmdShowVolMenu2() { loadCtxMenu("VolMenu2").open(); }
        function cmdShowVolMenu3() { loadCtxMenu("VolMenu3").open(); }

        function cmdShowVolDetailsDialog(title, capacity, free, used, usage)
        {
            if (dlg.dlgVolDetails.status != Loader.Ready)
            {
                //console.log("Loading DiskDetailsDialog");
                dlg.dlgVolDetails.source = "DiskDetailsDialog.qml";
            }

            dlg.dlgVolDetails.item.titleText = title;
            dlg.dlgVolDetails.item.usedText = used;
            dlg.dlgVolDetails.item.freeText = free;
            dlg.dlgVolDetails.item.capacityText = capacity;
            dlg.dlgVolDetails.item.percentUsed = usage;

            dlg.dlgVolDetails.item.open();
        }
    }

    function setInverted() { titleBar.inverted = app.InvertedTheme(); }

    onStatusChanged: {
        if (status == PageStatus.Activating)
            mainForm.UpdateFreeSpaces();
    }

    Component.onCompleted: {
        Dynamic.init(app, appWindow);
        app.OnMainFormLoaded(mainForm);
        theme.inverted = app.InvertedTheme();
    }
}
