import QtQuick 1.1
import com.nokia.meego 1.0
import myExplorer.types 1.0
import "Dynamic.js" as Dynamic
import "DynamicGlobal.js" as DynamicGlobal

MilPageStackWindow {
    id: appWindow

    initialPage: mainPage
    showStatusBar: app.ShowStatusBar();

    MainForm
    {
        id: mainPage
    }

    Item
    {
        id: menus
        anchors.fill: parent
        visible: false
    }

    Component {
        id: autoDlgComp

        AutoQueryDialog {
            // Prevent closing by clicking outside of the dialog
            signal privateClicked
            onPrivateClicked: {}
        }
    }

    Component {
        id: queryDlgComp

        QueryDialog {
            // Prevent closing by clicking outside of the dialog
            signal privateClicked
            onPrivateClicked: {}
        }
    }

    QtObject {
        id: d

        property variant aMsgDlg: null
        property variant aSettingsDlg: null
        property variant aViewOptionsDlg: null

        property variant mMainFormMainMenu: null

        property string updateUrl
    }

    Connections {
        target: app

        onUpdateAvailable: {
            d.updateUrl = strUrl;
            var aDlg = Dynamic.createObject(null, autoDlgComp, {
                                              titleText: strTitle,
                                              message: strText,
                                              acceptButtonText: qsTr("Cancel"),
                                              rejectButtonText: qsTr("Update")}
                                          );
            aDlg.accepted.connect(app.updateAccepted);
            aDlg.open();
        }

        onLicenseExpired: {
            var dlg = showMsg2(qsTr("License error"), qsTr("Please purchase myExplorer from Nokia store"));
            dlg.rejected.connect(licenseError);
        }
    }

    function licenseError() {
        app.OpenExternalUrl("http://store.ovi.com/content/232911");
        Qt.quit();
    }

    function updateAccepted() {
        app.OpenExternalUrl(d.updateUrl);
        Qt.quit();
    }

    function getCachedItem(pname, comp, properties) {
        return d[pname] = Dynamic.createObject(d[pname], comp, properties);
    }

    function getGlobalCachedItem(pname, comp, properties) {
        return d[pname] = DynamicGlobal.createObject(d[pname], comp, properties);
    }

    function getCachedMenu(mname) {
        var pname = "m" + mname;
        return d[pname] = Dynamic.createObject(d[pname], mname + ".qml", {}, menus);
    }

    function getGlobalCachedMenu(mname) {
        var pname = "m" + mname;
        return d[pname] = DynamicGlobal.createObject(d[pname], mname + ".qml", {}, menus);
    }

    //
    // Methods
    //

    function cmdPop() { appWindow.pageStack.pop(); }

    function cmdOpenFolderForm() {
        appWindow.pageStack.push(Qt.resolvedUrl("FolderForm.qml"));
    }

    function cmdAddNetworkFolder()
    {
        app.OnVolAdd();
        appWindow.pageStack.push(Qt.resolvedUrl("RemoteFolderForm.qml"));
    }

    function cmdShowVolRemoveMsgBox(msgText)
    {
        var aDlg = Dynamic.createObject(null, autoDlgComp, {
                                          message: msgText,
                                          acceptButtonText: qsTr("Yes"),
                                          rejectButtonText: qsTr("No")
                                      });
        aDlg.accepted.connect(app.DoVolRemove);
        aDlg.open();
    }

    function cmdShowRemoteFolderForm(nbtName, shareName, userName, password, ipAddress, winsServer, dnsName, port)
    {
        var form = appWindow.pageStack.push(Qt.resolvedUrl("RemoteFolderForm.qml"));
        form.setForEdit(nbtName, shareName, userName, password, ipAddress, winsServer, dnsName, port);
    }

    function cmdShowSettingsDialog()
    {
        var dlg = getGlobalCachedItem("aSettingsDlg", "SettingsDialog.qml");
        dlg.open();
    }

    function showMsg(title, text)
    {
        var dlg = getCachedItem("aMsgDlg", queryDlgComp, {
                                           titleText: title,
                                           message: text,
                                           rejectButtonText: qsTr("Close")}
                                          );
        dlg.open();
    }

    function showMsg2(title, text) {
        var dlg = Dynamic.createObject(null, autoDlgComp, {
                                           titleText: title,
                                           message: text,
                                           rejectButtonText: qsTr("Close")}
                                       );
        dlg.open();
        return dlg;
    }

    function cmdExit() {
        if (app.ExitPrompt()) {
            var aDlg = Dynamic.createObject(null, autoDlgComp, {
                                              message: qsTr("Exit myExplorer?"),
                                              acceptButtonText: qsTr("Yes"),
                                              rejectButtonText: qsTr("No") }
                                              );
            aDlg.accepted.connect(Qt.quit);
            aDlg.open();
        } else {
            Qt.quit();
        }
    }

    function aboutDlg() {
        var aDlg = Dynamic.createObject(null, autoDlgComp, {
                                          titleText: "myExplorer 2.3.1",
                                          message: qsTr("Copyright (c) 2011-15 Ilko Tsenov"),
                                          rejectButtonText: qsTr("Close") }
                                          );
        aDlg.open();
    }

    function setInvTheme(inv) { theme.inverted = inv; mainPage.setInverted(); }

    function showHelp(pageUrl) {
        appWindow.pageStack.push(Qt.resolvedUrl("HelpForm.qml"), {url: app.GetHelpUrl(pageUrl)});
    }

    function cmdOpenTextForm(fv) {
        appWindow.pageStack.push(Qt.resolvedUrl("TextPage.qml"), {folderView: fv});
    }

    function openViewOptionsDlg() {
        var dlg = getGlobalCachedItem("aViewOptionsDlg", "ViewOptionsDialog.qml");
        dlg.openDlg();
    }

//    function testComponents() {
//        for (var i = 0; i < 1000; ++i) {
//            var dlg = Dynamic.createObject(null, "TransferDialog.qml");
//            dlg.destroy();
//        }
//    }
}
